@@ -1,4 +1,4 @@
-/* $Id: c2c.c,v 1.57 2004/03/04 19:18:18 mad Exp $ */
+/* $Id: c2c.c,v 1.59 2006/03/15 10:21:01 mad Exp $ */
 /*
  * Copyright (c) 2003, Alexander Marx
  * All rights reserved.
@@ -478,7 +478,10 @@ int courier_subscribe(char *root, char *dir, int is_root) {
 					if(strlen(&p[len])!=0) {
 						char *e=strrchr(&p[len], '\t');
 						if(e) *e='\0';
-						fprintf(fo, "INBOX.%s\n", &p[len]);
+						if(dovecot)
+							fprintf(fo, "%s\n", &p[len]);
+						else
+							fprintf(fo, "INBOX.%s\n", &p[len]);
 					}
 				}
 				freeSTR(t);
@@ -530,6 +533,8 @@ int courier_mkdir(char *root, char *dir, int is_root) {
 int courier_cpmail(char *src, unsigned long size, char *dst_a, char *dst_b, unsigned long *rsize) {
 	eSTR *m, *d;
 	char is[32];
+	struct stat s;
+	struct timeval tv[2];
 	int i;
 
 	/* read the mailfile */
@@ -547,6 +552,13 @@ int courier_cpmail(char *src, unsigned long size, char *dst_a, char *dst_b, unsi
 	/* write the stripped file */
 	outfileSTR(m, d->str);
 
+	/* fix file modification time (=imap received time) */
+	stat(src, &s);
+	tv[0].tv_sec=s.st_atime;
+	tv[1].tv_sec=s.st_mtime;
+	utimes(d->str, tv);
+	
+
 	freeSTR(m);
 	freeSTR(d);
 
